--
-- FendtFarmer2
-- Specialization for Fendt Farmer 2 by Michl2
--
-- @authors  	Called in their parts of the script
-- @version 	v1.0
-- @date  		25/08/13
-- www.schwabenmodding.bplaced.net

Farmer2Animations = {};

function Farmer2Animations.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function Farmer2Animations:load(xmlFile)

	-- Tachozeiger / Speedometer animation ( by modelleicher)
	self.tachoZeiger = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Farmer2Animations.TachoZeiger#zeigerIndex"));
	self.tachoZeigerMultiplicator = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.Farmer2Animations.TachoZeiger#multiplicator"), 10);
	self.tachoZeigerMaxRotation = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.Farmer2Animations.TachoZeiger#maxRotation"), 245);
	
	-- Temperaturzeiger / temperature Display animation ( by modelleicher)
	self.temperaturZeiger = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Farmer2Animations.TemperaturZeiger#zeigerIndex"));
	self.temperaturZeigerMaxRot = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.Farmer2Animations.TemperaturZeiger#maxRotation"));
	self.tempCnt = 0;

	-- Zapfwellenstummel / powershaftstub ( by modelleicher)
	self.zapfwelleStummel = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Farmer2Animations.ZapfwellenStummel#index"));
	self.zapfwelleStummelSpeed = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.Farmer2Animations.ZapfwellenStummel#speed"),1);

	--Gaspedal / accelerator animation ( by fendtfahrer95, BM Modding)
	local gaspedalNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Farmer2Animations.gaspedal#index"));
    if gaspedalNode ~= nil then
        self.gaspedal = {};
        self.gaspedal.node = gaspedalNode;    
		self.gaspedal.maxSpeed = getXMLInt(xmlFile, "vehicle.Farmer2Animations.gaspedal#maxSpeed");
		local x1,y1,z1 = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.Farmer2Animations.gaspedal#minRot"));
		local x2,y2,z2 = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.Farmer2Animations.gaspedal#maxRot"));		
		self.gaspedal.rotMin = {math.rad(Utils.getNoNil(x1,0)),math.rad(Utils.getNoNil(y1,0)),math.rad(Utils.getNoNil(z1,0))};
		self.gaspedal.rotMax = {math.rad(Utils.getNoNil(x2,0)),math.rad(Utils.getNoNil(y2,0)),math.rad(Utils.getNoNil(z2,0))};
    end;
	
	--Bremspedal / brake animation ( by fendtfahrer95, BM Modding)
    local bremspedalNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Farmer2Animations.bremspedal#index"));
    if bremspedalNode ~= nil then
        self.bremspedal = {};
        self.bremspedal.node = bremspedalNode;
		local x1,y1,z1 = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.Farmer2Animations.bremspedal#minRot"));
		local x2,y2,z2 = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.Farmer2Animations.bremspedal#maxRot"));
		self.bremspedal.rotMin = {math.rad(Utils.getNoNil(x1,0)),math.rad(Utils.getNoNil(y1,0)),math.rad(Utils.getNoNil(z1,0))};			
		self.bremspedal.rotMax = {math.rad(Utils.getNoNil(x2,0)),math.rad(Utils.getNoNil(y2,0)),math.rad(Utils.getNoNil(z2,0))};
        self.bremspedal.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.Farmer2Animations.bremspedal#rotTime"), 1)*1000;
        self.bremspedalIsActive = false;
    end;	
	
	-- Handgashebel ( by modelleicher)
	self.handgasHebel = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Farmer2Animations.HandgasHebel#index"));
	self.handgasHebelTemp1Rot = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.Farmer2Animations.HandgasHebel#tempomat1rot"));
	self.handgasHebelTemp2Rot = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.Farmer2Animations.HandgasHebel#tempomat2rot"));
	self.handgasHebelTemp3Rot = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.Farmer2Animations.HandgasHebel#tempomat3rot"));
	self.handgasHebelTemp4Rot = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.Farmer2Animations.HandgasHebel#tempomat4rot"));	
	self.hgHrot = 0;
	

end;

function Farmer2Animations:delete()
end;

function Farmer2Animations:mouseEvent(posX, posY, isDown, isUp, button)
end;

function Farmer2Animations:keyEvent(unicode, sym, modifier, isDown)
end;

function Farmer2Animations:updateTick(dt)
	if self:getIsActive() then		
			if self.gaspedal ~= nil then		
				local percent = (self.lastSpeed*self.speedDisplayScale*3600) / self.gaspedal.maxSpeed;
				local minRot = self.gaspedal.rotMin;
				local maxRot = self.gaspedal.rotMax;
					
				local x = minRot[1] + (maxRot[1] - minRot[1]) * percent;
				local y = minRot[2] + (maxRot[2] - minRot[2]) * percent;
				local z = minRot[3] + (maxRot[3] - minRot[3]) * percent;
				setRotation(self.gaspedal.node, x, y, z);
			end;			
			-- check for braking
			if self.bremspedal ~= nil then
				local x, y, z = getRotation(self.bremspedal.node);
				local rot = {x,y,z};
				local direction = 1;
				if self.invertedDrivingDirection then
				    direction = -1;
				else
				    direction = 1;
				end;
				local braking = math.abs(Utils.sign(self.lastAcceleration)+ (-self.movingDirection * direction)) == 2;
				local newRot = Utils.getMovedLimitedValues(rot, self.bremspedal.rotMax, self.bremspedal.rotMin, 3, self.bremspedal.rotTime, dt, braking);
				setRotation(self.bremspedal.node, unpack(newRot));
			end;
		
	end;
end;

function Farmer2Animations:update(dt)
	if self:getIsActive() then
		if self.isMotorStarted then
			-- Tachozeiger / speedometer animation
			self.kmhMath = math.min(100, math.max(0, self.lastSpeed*self.speedDisplayScale*3600));
			local zeigerRotation = self.kmhMath * self.tachoZeigerMultiplicator;
			if zeigerRotation <= self.tachoZeigerMaxRotation then
				setRotation(self.tachoZeiger, 0, Utils.degToRad(zeigerRotation), 0);
			else
				setRotation(self.tachoZeiger, 0, Utils.degToRad(self.tachoZeigerMaxRotation), 0);	
			end;
			
			-- Temperaturanzeiger / temperature display animation und / and berechnung / calculation
			if self.tempCnt < 3000 then
				setRotation(self.temperaturZeiger, 0, Utils.degToRad(-(self.temperaturZeigerMaxRot/10000)*self.tempCnt), 0);
				self.tempCnt = self.tempCnt + 2;
			elseif self.tempCnt > 3000 and self.tempCnt < 6000 then
				setRotation(self.temperaturZeiger, 0, Utils.degToRad(-(self.temperaturZeigerMaxRot/10000)*self.tempCnt), 0);
				self.tempCnt = math.min(self.tempCnt + 2, 10000);			
			else
				setRotation(self.temperaturZeiger, 0, Utils.degToRad(-(self.temperaturZeigerMaxRot/10000)*self.tempCnt), 0);
				self.tempCnt = math.min(self.tempCnt + 2, 10000);
			end;
			
			-- Zapfwellenstummel
			rotate(self.zapfwelleStummel, 0, 0, self.zapfwelleStummelSpeed / 10 * dt);
		
 		    -- Handgashebel
			if self.handgasHebel ~= nil then
				local rot = 0;
				if self.motor.speedLevel == 1 then
					rot = self.handgasHebelTemp1Rot
				elseif self.motor.speedLevel == 2 then
					rot = self.handgasHebelTemp2Rot
				elseif self.motor.speedLevel == 3 then
					rot = self.handgasHebelTemp3Rot
				elseif self.motor.speedLevel == 4 then
					rot = self.handgasHebelTemp4Rot
				end;
				if self.hgHrot < rot then
					self.hgHrot = math.min(rot, self.hgHrot +1);
					setRotation(self.handgasHebel, 0, Utils.degToRad(self.hgHrot), 0)
				elseif self.hgHrot > rot then
					self.hgHrot = math.max(rot, self.hgHrot -1);
					setRotation(self.handgasHebel, 0, Utils.degToRad(self.hgHrot), 0)
				end;
			end;

		end;

	else
		self.tempCnt = math.max(self.tempCnt - 0.5, 0);
	end;
end;

function Farmer2Animations:draw()
end;